NavigationBarProperties class

Constructors

const
factory
factory
factory

Properties

brightness → Brightness?
final
color → Color?
final
contrastEnforced → bool?
final
dividerColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transparency → bool?
final

Methods

modify({bool? contrastEnforced, Color? color, Color? dividerColor, Brightness? brightness, bool? transparency}) → NavigationBarProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited