AndrossyInstance<T extends AndrossyController> class

Properties

androssy ↔ Androssy
getter/setter pair
context → BuildContext
no setter
controller → T
no setter
currentUid → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → AndrossyUser
User properties
no setter

Methods

attach(BuildContext context, T controller) → void
clear() → void
close([String? id]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

find<T extends AndrossyController>([String? id]) → AndrossyInstance<T>?
findController<T extends AndrossyController>([String? id]) → T?
init<T extends AndrossyController>(String? id) → AndrossyInstance<T>