ContentStyle class

Constructors

ContentStyle({FontWeight? fontWeight, TextAlign? textAlign, Color textColor = Colors.black, double textSize = 14})
const

Properties

fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
final
textColor → Color
final
textSize → double
final

Methods

copy({FontWeight? fontWeight, TextAlign? textAlign, Color? textColor, double? textSize}) → ContentStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited