EditLayout<T extends EditLayoutController> class

Inheritance

Constructors

EditLayout({Key? key, T? controller, OnViewActivator? onActivator, OnViewChangeListener? onChange, OnViewErrorListener? onError, OnViewHoverListener? onHover, OnViewValidListener? onValid, OnViewValidatorListener? onValidator, ViewClickEffect? clickEffect, OnViewClickListener? onClick, OnViewClickListener? onDoubleClick, OnViewClickListener? onLongClick, OnViewToggleListener? onToggleClick, OnViewNotifyListener<T>? onClickHandler, OnViewNotifyListener<T>? onDoubleClickHandler, OnViewNotifyListener<T>? onLongClickHandler, bool? absorbMode, bool? activated, Color? background, ValueState<Color>? backgroundState, BlendMode? backgroundBlendMode, Gradient? backgroundGradient, ValueState<Gradient>? backgroundGradientState, DecorationImage? backgroundImage, ValueState<DecorationImage>? backgroundImageState, Clip? clipBehavior, double? dimensionRatio, double? elevation, bool? enabled, bool? expandable, Color? foreground, BlendMode? foregroundBlendMode, Gradient? foregroundGradient, DecorationImage? foregroundImage, int? flex, Alignment? gravity, double? height, ValueState<double>? heightState, double? heightMax, double? heightMin, Color hoverColor = Colors.transparent, Axis? orientation, ViewPosition? position, ViewPositionType? positionType, Color pressedColor = Colors.transparent, Color rippleColor = Colors.transparent, bool? scrollable, ScrollController? scrollController, ViewScrollingType? scrollingType, ViewShape? shape, Matrix4? transform, Alignment? transformGravity, bool? visibility, double? width, ValueState<double>? widthState, double? widthMax, double? widthMin, int? animation, Curve? animationType, ImageFilter? backdropFilter, BlendMode? backdropMode, Color? borderColor, ValueState<Color>? borderColorState, double? borderSize, ValueState<double>? borderSizeState, double? borderHorizontal, ValueState<double>? borderHorizontalState, double? borderVertical, ValueState<double>? borderVerticalState, double? borderTop, ValueState<double>? borderTopState, double? borderBottom, ValueState<double>? borderBottomState, double? borderStart, ValueState<double>? borderStartState, double? borderEnd, ValueState<double>? borderEndState, double? borderStrokeAlign, double? borderRadius, ValueState<double>? borderRadiusState, double? borderRadiusBL, ValueState<double>? borderRadiusBLState, double? borderRadiusBR, ValueState<double>? borderRadiusBRState, double? borderRadiusTL, ValueState<double>? borderRadiusTLState, double? borderRadiusTR, ValueState<double>? borderRadiusTRState, bool indicatorVisible = false, double? margin, double? marginHorizontal, double? marginVertical, double? marginTop, double? marginBottom, double? marginStart, double? marginEnd, EdgeInsets? marginCustom, double? opacity, ValueState<double>? opacityState, bool opacityAlwaysIncludeSemantics = false, double? padding, double? paddingHorizontal, double? paddingVertical, double? paddingTop, double? paddingBottom, double? paddingStart, double? paddingEnd, EdgeInsets? paddingCustom, double? shadow, double? shadowBlurRadius, BlurStyle? shadowBlurStyle, Color? shadowColor, ViewShadowType? shadowType, double? shadowSpreadRadius, double? shadowHorizontal, double? shadowVertical, double? shadowStart, double? shadowEnd, double? shadowTop, double? shadowBottom, LayoutGravity? layoutGravity, MainAxisAlignment? mainGravity, MainAxisSize mainAxisSize = MainAxisSize.min, CrossAxisAlignment? crossGravity, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, OnViewChangeListener? onPaging, List<Widget>? children, int initialCheckTime = 500})
const

Properties

absorbMode → bool?
finalinherited
activated → bool?
finalinherited
animation → int?
finalinherited
animationType → Curve?
finalinherited
backdropFilter → ImageFilter?
BACKDROP PROPERTIES
finalinherited
backdropMode → BlendMode?
finalinherited
background → Color?
finalinherited
backgroundBlendMode → BlendMode?
finalinherited
backgroundGradient → Gradient?
finalinherited
backgroundGradientState → ValueState<Gradient>?
finalinherited
backgroundImage → DecorationImage?
finalinherited
backgroundImageState → ValueState<DecorationImage>?
finalinherited
backgroundState → ValueState<Color>?
finalinherited
borderBottom → double?
finalinherited
borderBottomState → ValueState<double>?
finalinherited
borderColor → Color?
BORDER PROPERTIES
finalinherited
borderColorState → ValueState<Color>?
finalinherited
borderEnd → double?
finalinherited
borderEndState → ValueState<double>?
finalinherited
borderHorizontal → double?
finalinherited
borderHorizontalState → ValueState<double>?
finalinherited
borderRadius → double?
BORDER RADIUS PROPERTIES
finalinherited
borderRadiusBL → double?
finalinherited
borderRadiusBLState → ValueState<double>?
finalinherited
borderRadiusBR → double?
finalinherited
borderRadiusBRState → ValueState<double>?
finalinherited
borderRadiusState → ValueState<double>?
finalinherited
borderRadiusTL → double?
finalinherited
borderRadiusTLState → ValueState<double>?
finalinherited
borderRadiusTR → double?
finalinherited
borderRadiusTRState → ValueState<double>?
finalinherited
borderSize → double?
finalinherited
borderSizeState → ValueState<double>?
finalinherited
borderStart → double?
finalinherited
borderStartState → ValueState<double>?
finalinherited
borderStrokeAlign → double?
finalinherited
borderTop → double?
finalinherited
borderTopState → ValueState<double>?
finalinherited
borderVertical → double?
finalinherited
borderVerticalState → ValueState<double>?
finalinherited
child → Widget?
finalinherited
children → List<Widget>?
finalinherited
clickEffect → ViewClickEffect?
CLICK PROPERTIES
finalinherited
clipBehavior → Clip?
finalinherited
controller → T?
ROOT PROPERTIES
finalinherited
crossGravity → CrossAxisAlignment?
finalinherited
dimensionRatio → double?
finalinherited
elevation → double?
finalinherited
enabled → bool?
finalinherited
expandable → bool?
finalinherited
flex → int?
finalinherited
foreground → Color?
finalinherited
foregroundBlendMode → BlendMode?
finalinherited
foregroundGradient → Gradient?
finalinherited
foregroundImage → DecorationImage?
finalinherited
gravity → Alignment?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
heightMax → double?
finalinherited
heightMin → double?
finalinherited
heightState → ValueState<double>?
finalinherited
hoverColor → Color
finalinherited
indicatorVisible → bool
INDICATOR PROPERTIES
finalinherited
initialCheckTime → int
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutGravity → LayoutGravity?
finalinherited
mainAxisSize → MainAxisSize
finalinherited
mainGravity → MainAxisAlignment?
finalinherited
margin → double?
MARGIN PROPERTIES
finalinherited
marginBottom → double?
finalinherited
marginCustom → EdgeInsets?
finalinherited
marginEnd → double?
finalinherited
marginHorizontal → double?
finalinherited
marginStart → double?
finalinherited
marginTop → double?
finalinherited
marginVertical → double?
finalinherited
onActivator → OnViewActivator?
CALLBACK PROPERTIES
finalinherited
onChange → OnViewChangeListener?
finalinherited
onClick → OnViewClickListener?
finalinherited
onClickHandler → OnViewNotifyListener<T>?
finalinherited
onDoubleClick → OnViewClickListener?
finalinherited
onDoubleClickHandler → OnViewNotifyListener<T>?
finalinherited
onError → OnViewErrorListener?
finalinherited
onHover → OnViewHoverListener?
finalinherited
onLongClick → OnViewClickListener?
finalinherited
onLongClickHandler → OnViewNotifyListener<T>?
finalinherited
onPaging → OnViewChangeListener?
finalinherited
onToggleClick → OnViewHoverListener?
finalinherited
onValid → OnViewHoverListener?
finalinherited
onValidator → OnViewValidatorListener?
finalinherited
opacity → double?
OPACITY PROPERTIES
finalinherited
opacityAlwaysIncludeSemantics → bool
finalinherited
opacityState → ValueState<double>?
finalinherited
orientation → Axis?
finalinherited
padding → double?
PADDING PROPERTIES
finalinherited
paddingBottom → double?
finalinherited
paddingCustom → EdgeInsets?
finalinherited
paddingEnd → double?
finalinherited
paddingHorizontal → double?
finalinherited
paddingStart → double?
finalinherited
paddingTop → double?
finalinherited
paddingVertical → double?
finalinherited
position → ViewPosition?
finalinherited
positionType → ViewPositionType?
finalinherited
pressedColor → Color
finalinherited
rippleColor → Color
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool?
finalinherited
scrollController → ScrollController?
finalinherited
scrollingType → ViewScrollingType?
finalinherited
shadow → double?
SHADOW PROPERTIES
finalinherited
shadowBlurRadius → double?
finalinherited
shadowBlurStyle → BlurStyle?
finalinherited
shadowBottom → double?
finalinherited
shadowColor → Color?
finalinherited
shadowEnd → double?
finalinherited
shadowHorizontal → double?
finalinherited
shadowSpreadRadius → double?
finalinherited
shadowStart → double?
finalinherited
shadowTop → double?
finalinherited
shadowType → ViewShadowType?
finalinherited
shadowVertical → double?
finalinherited
shape → ViewShape?
finalinherited
textBaseline → TextBaseline?
finalinherited
textDirection → TextDirection?
finalinherited
transform → Matrix4?
finalinherited
transformGravity → Alignment?
finalinherited
verticalDirection → VerticalDirection
finalinherited
visibility → bool?
finalinherited
width → double?
finalinherited
widthMax → double?
finalinherited
widthMin → double?
finalinherited
widthState → ValueState<double>?
finalinherited
wrapper → bool?
finalinherited

Methods

attach(BuildContext context, T controller) → Widget?
inherited
attachController(T controller) → T
override
build(BuildContext context, T controller, Widget parent) → Widget
inherited
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<YMRView<T>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
initController() → T
override
initRootProperties() → ViewRoots
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChangeDependencies(BuildContext context, T controller) → void
inherited
onDispose(BuildContext context, T controller) → void
inherited
onInit(BuildContext context, T controller) → void
inherited
onReady(BuildContext context, T controller) → void
override
onToggleHandler(BuildContext context, T controller) → void
inherited
onUpdateWidget(BuildContext context, T controller, dynamic oldWidget) → void
inherited
onViewCreated(BuildContext context, T controller) → void
inherited
root(BuildContext context, T controller, Widget parent) → Widget
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited