EditText<T extends EditTextController> class

Inheritance

Constructors

EditText({Key? key, T? controller, OnViewActivator? onActivator, OnViewChangeListener? onChange, OnViewErrorListener? onError, OnViewHoverListener? onHover, OnViewValidListener? onValid, OnViewValidatorListener? onValidator, ViewClickEffect? clickEffect, OnViewClickListener? onClick, OnViewClickListener? onDoubleClick, OnViewClickListener? onLongClick, OnViewToggleListener? onToggleClick, OnViewNotifyListener<T>? onClickHandler, OnViewNotifyListener<T>? onDoubleClickHandler, OnViewNotifyListener<T>? onLongClickHandler, bool? absorbMode, bool? activated, Color? background, ValueState<Color>? backgroundState, BlendMode? backgroundBlendMode, Gradient? backgroundGradient, ValueState<Gradient>? backgroundGradientState, DecorationImage? backgroundImage, ValueState<DecorationImage>? backgroundImageState, Clip? clipBehavior, double? dimensionRatio, double? elevation, bool? enabled, bool? expandable, Color? foreground, BlendMode? foregroundBlendMode, Gradient? foregroundGradient, DecorationImage? foregroundImage, int? flex, Alignment? gravity, double? height, ValueState<double>? heightState, double? heightMax, double? heightMin, Color hoverColor = Colors.transparent, Axis? orientation, ViewPosition? position, ViewPositionType? positionType, Color pressedColor = Colors.transparent, Color rippleColor = Colors.transparent, bool? scrollable, ScrollController? scrollController, ViewScrollingType? scrollingType, ViewShape? shape, Matrix4? transform, Alignment? transformGravity, bool? visibility, double? width, ValueState<double>? widthState, double? widthMax, double? widthMin, int? animation, Curve? animationType, ImageFilter? backdropFilter, BlendMode? backdropMode, Color? borderColor, ValueState<Color>? borderColorState, double? borderSize, ValueState<double>? borderSizeState, double? borderHorizontal, ValueState<double>? borderHorizontalState, double? borderVertical, ValueState<double>? borderVerticalState, double? borderTop, ValueState<double>? borderTopState, double? borderBottom, ValueState<double>? borderBottomState, double? borderStart, ValueState<double>? borderStartState, double? borderEnd, ValueState<double>? borderEndState, double? borderStrokeAlign, double? borderRadius, ValueState<double>? borderRadiusState, double? borderRadiusBL, ValueState<double>? borderRadiusBLState, double? borderRadiusBR, ValueState<double>? borderRadiusBRState, double? borderRadiusTL, ValueState<double>? borderRadiusTLState, double? borderRadiusTR, ValueState<double>? borderRadiusTRState, bool indicatorVisible = false, double? margin, double? marginHorizontal, double? marginVertical, double? marginTop, double? marginBottom, double? marginStart, double? marginEnd, EdgeInsets? marginCustom, double? opacity, ValueState<double>? opacityState, bool opacityAlwaysIncludeSemantics = false, double? padding, double? paddingHorizontal, double? paddingVertical, double? paddingTop, double? paddingBottom, double? paddingStart, double? paddingEnd, EdgeInsets? paddingCustom, double? shadow, double? shadowBlurRadius, BlurStyle? shadowBlurStyle, Color? shadowColor, ViewShadowType? shadowType, double? shadowSpreadRadius, double? shadowHorizontal, double? shadowVertical, double? shadowStart, double? shadowEnd, double? shadowTop, double? shadowBottom, int maxCharacters = 0, int? maxLines, double? letterSpacing, double lineSpacingExtra = 0, Locale? locale, double? wordSpacing, String? textFontFamily, FontStyle? textFontStyle, FontWeight? textFontWeight, TextDirection? textDirection, Color? selectionColor, StrutStyle? strutStyle, String? text, TextAlign? textAlign, bool textAllCaps = false, Color? textColor, TextHeightBehavior? textHeightBehavior, TextOverflow? textOverflow, double? textSize, TextStyle? textStyle, TextWidthBasis textWidthBasis = TextWidthBasis.parent, bool autoDisposeMode = true, String characters = "", String hint = "", Color? hintColor, int? minCharacters, Color? primary, Color? counterTextColor, ValueState<Color>? counterTextColorState, TextStyle? counterTextStyle, ValueState<TextStyle>? counterTextStyleState, FloatingVisibility counterVisibility = FloatingVisibility.hide, dynamic drawableEnd, ValueState? drawableEndState, EditTextDrawableBuilder<T>? drawableEndBuilder, double drawableEndSize = 24, ValueState<double>? drawableEndSizeState, double? drawableEndPadding, ValueState<double>? drawableEndPaddingState, Color? drawableEndTint, ValueState<Color>? drawableEndTintState, bool drawableEndVisible = true, bool drawableEndAsEye = false, dynamic drawableStart, ValueState? drawableStartState, EditTextDrawableBuilder<T>? drawableStartBuilder, double drawableStartSize = 24, ValueState<double>? drawableStartSizeState, double? drawableStartPadding, ValueState<double>? drawableStartPaddingState, Color? drawableStartTint, ValueState<Color>? drawableStartTintState, bool drawableStartVisible = true, Color? errorTextColor = const Color(0xFFFF7769), ValueState<Color>? errorTextColorState, TextStyle? errorTextStyle, ValueState<TextStyle>? errorTextStyleState, FloatingVisibility errorVisibility = FloatingVisibility.auto, Alignment? floatingAlignment, String? floatingText, TextStyle? floatingTextStyle, ValueState<TextStyle>? floatingTextStyleState, EdgeInsets floatingTextSpace = EdgeInsets.zero, FloatingVisibility floatingVisibility = FloatingVisibility.hide, String helperText = "", Color? helperTextColor, ValueState<Color>? helperTextColorState, TextStyle? helperTextStyle, ValueState<TextStyle>? helperTextStyleState, Widget? indicator, double indicatorSize = 24, Color? indicatorStrokeColor, ValueState<Color>? indicatorStrokeColorState, double indicatorStroke = 2, Color? indicatorStrokeBackground, ValueState<Color>? indicatorStrokeBackgroundState, bool autocorrect = true, List<String> autofillHints = const [], bool autoFocus = false, Clip clipBehaviorText = Clip.hardEdge, Color? cursorColor, double? cursorHeight, bool cursorOpacityAnimates = false, Radius? cursorRadius, double cursorWidth = 2, ContentInsertionConfiguration? contentInsertionConfiguration, EditTextContextMenuBuilder? contextMenuBuilder = _defaultContextMenuBuilder, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool enableIMEPersonalizedLearning = true, bool? enableInteractiveSelection, bool enableSuggestions = true, bool expands = false, String ignorableCharacters = "", TextInputAction? inputAction, List<TextInputFormatter>? inputFormatters, TextInputType? inputType, Brightness keyboardAppearance = Brightness.light, TextMagnifierConfiguration magnifierConfiguration = TextMagnifierConfiguration.disabled, bool maxCharactersAsLimit = true, int? minLines, MouseCursor? mouseCursor, bool? obscureText, String obscuringCharacter = '•', bool readOnly = false, String? restorationId, bool scribbleEnabled = true, ScrollController? scrollControllerText, EdgeInsets scrollPaddingText = const EdgeInsets.all(20), ScrollPhysics? scrollPhysicsText, Color? secondaryColor, TextSelectionControls? selectionControls, BoxHeightStyle selectionHeightStyle = BoxHeightStyle.tight, BoxWidthStyle selectionWidthStyle = BoxWidthStyle.tight, bool? showCursor, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextCapitalization textCapitalization = TextCapitalization.none, UndoHistoryController? undoController, EditTextPrivateCommandListener? onAppPrivateCommand, EditTextVoidListener? onEditingComplete, EditTextSubmitListener? onSubmitted, EditTextTapOutsideListener? onTapOutside, Color? underlineColor, ValueState<Color>? underlineColorState, double? underlineHeight, ValueState<double>? underlineHeightState})
const

Properties

absorbMode → bool?
finalinherited
activated → bool?
finalinherited
animation → int?
finalinherited
animationType → Curve?
finalinherited
autocorrect → bool
TEXT FIELD PROPERTIES
final
autoDisposeMode → bool
BASE PROPERTIES
final
autofillHints → List<String>
final
autoFocus → bool
final
backdropFilter → ImageFilter?
BACKDROP PROPERTIES
finalinherited
backdropMode → BlendMode?
finalinherited
background → Color?
finalinherited
backgroundBlendMode → BlendMode?
finalinherited
backgroundGradient → Gradient?
finalinherited
backgroundGradientState → ValueState<Gradient>?
finalinherited
backgroundImage → DecorationImage?
finalinherited
backgroundImageState → ValueState<DecorationImage>?
finalinherited
backgroundState → ValueState<Color>?
finalinherited
borderBottom → double?
finalinherited
borderBottomState → ValueState<double>?
finalinherited
borderColor → Color?
BORDER PROPERTIES
finalinherited
borderColorState → ValueState<Color>?
finalinherited
borderEnd → double?
finalinherited
borderEndState → ValueState<double>?
finalinherited
borderHorizontal → double?
finalinherited
borderHorizontalState → ValueState<double>?
finalinherited
borderRadius → double?
BORDER RADIUS PROPERTIES
finalinherited
borderRadiusBL → double?
finalinherited
borderRadiusBLState → ValueState<double>?
finalinherited
borderRadiusBR → double?
finalinherited
borderRadiusBRState → ValueState<double>?
finalinherited
borderRadiusState → ValueState<double>?
finalinherited
borderRadiusTL → double?
finalinherited
borderRadiusTLState → ValueState<double>?
finalinherited
borderRadiusTR → double?
finalinherited
borderRadiusTRState → ValueState<double>?
finalinherited
borderSize → double?
finalinherited
borderSizeState → ValueState<double>?
finalinherited
borderStart → double?
finalinherited
borderStartState → ValueState<double>?
finalinherited
borderStrokeAlign → double?
finalinherited
borderTop → double?
finalinherited
borderTopState → ValueState<double>?
finalinherited
borderVertical → double?
finalinherited
borderVerticalState → ValueState<double>?
finalinherited
characters → String
final
child → Widget?
finalinherited
clickEffect → ViewClickEffect?
CLICK PROPERTIES
finalinherited
clipBehavior → Clip?
finalinherited
clipBehaviorText → Clip
final
contentInsertionConfiguration → ContentInsertionConfiguration?
final
contextMenuBuilder → EditTextContextMenuBuilder?
final
controller → T?
ROOT PROPERTIES
finalinherited
counterTextColor → Color?
COUNTER TEXT PROPERTIES
final
counterTextColorState → ValueState<Color>?
final
counterTextStyle → TextStyle?
final
counterTextStyleState → ValueState<TextStyle>?
final
counterVisibility → FloatingVisibility
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorOpacityAnimates → bool
final
cursorRadius → Radius?
final
cursorWidth → double
final
dimensionRatio → double?
finalinherited
dragStartBehavior → DragStartBehavior
final
drawableEnd → dynamic
DRAWABLE END PROPERTIES
final
drawableEndAsEye → bool
final
drawableEndBuilder → EditTextDrawableBuilder<T>?
final
drawableEndPadding → double?
final
drawableEndPaddingState → ValueState<double>?
final
drawableEndSize → double
final
drawableEndSizeState → ValueState<double>?
final
drawableEndState → ValueState?
final
drawableEndTint → Color?
final
drawableEndTintState → ValueState<Color>?
final
drawableEndVisible → bool
final
drawableStart → dynamic
DRAWABLE START PROPERTIES
final
drawableStartBuilder → EditTextDrawableBuilder<T>?
final
drawableStartPadding → double?
final
drawableStartPaddingState → ValueState<double>?
final
drawableStartSize → double
final
drawableStartSizeState → ValueState<double>?
final
drawableStartState → ValueState?
final
drawableStartTint → Color?
final
drawableStartTintState → ValueState<Color>?
final
drawableStartVisible → bool
final
elevation → double?
finalinherited
ellipsis → String?
finalinherited
enabled → bool?
finalinherited
enableIMEPersonalizedLearning → bool
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool
final
errorTextColor → Color?
final
errorTextColorState → ValueState<Color>?
final
errorTextStyle → TextStyle?
final
errorTextStyleState → ValueState<TextStyle>?
final
errorVisibility → FloatingVisibility
ERROR TEXT PROPERTIES
final
expandable → bool?
finalinherited
expands → bool
final
flex → int?
finalinherited
floatingAlignment → Alignment?
FLOATING TEXT PROPERTIES
final
floatingText → String?
final
floatingTextSpace → EdgeInsets
final
floatingTextStyle → TextStyle?
final
floatingTextStyleState → ValueState<TextStyle>?
final
floatingVisibility → FloatingVisibility
final
foreground → Color?
finalinherited
foregroundBlendMode → BlendMode?
finalinherited
foregroundGradient → Gradient?
finalinherited
foregroundImage → DecorationImage?
finalinherited
gravity → Alignment?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
heightMax → double?
finalinherited
heightMin → double?
finalinherited
heightState → ValueState<double>?
finalinherited
helperText → String
HELPER TEXT PROPERTIES
final
helperTextColor → Color?
final
helperTextColorState → ValueState<Color>?
final
helperTextStyle → TextStyle?
final
helperTextStyleState → ValueState<TextStyle>?
final
hint → String
final
hintColor → Color?
final
hoverColor → Color
finalinherited
ignorableCharacters → String
final
indicator → Widget?
INDICATOR PROPERTIES
final
indicatorSize → double
final
indicatorStroke → double
final
indicatorStrokeBackground → Color?
final
indicatorStrokeBackgroundState → ValueState<Color>?
final
indicatorStrokeColor → Color?
final
indicatorStrokeColorState → ValueState<Color>?
final
indicatorVisible → bool
INDICATOR PROPERTIES
finalinherited
inputAction → TextInputAction?
final
inputFormatters → List<TextInputFormatter>?
final
inputType → TextInputType?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness
final
letterSpacing → double?
finalinherited
lineSpacingExtra → double
finalinherited
locale → Locale?
finalinherited
magnifierConfiguration → TextMagnifierConfiguration
final
margin → double?
MARGIN PROPERTIES
finalinherited
marginBottom → double?
finalinherited
marginCustom → EdgeInsets?
finalinherited
marginEnd → double?
finalinherited
marginHorizontal → double?
finalinherited
marginStart → double?
finalinherited
marginTop → double?
finalinherited
marginVertical → double?
finalinherited
maxCharacters → int
finalinherited
maxCharactersAsLimit → bool
final
maxLines → int?
finalinherited
minCharacters → int?
final
minLines → int?
final
mouseCursor → MouseCursor?
final
obscureText → bool?
final
obscuringCharacter → String
final
onActivator → OnViewActivator?
CALLBACK PROPERTIES
finalinherited
onAppPrivateCommand → EditTextPrivateCommandListener?
final
onChange → OnViewChangeListener?
finalinherited
onClick → OnViewClickListener?
finalinherited
onClickHandler → OnViewNotifyListener<T>?
finalinherited
onDoubleClick → OnViewClickListener?
finalinherited
onDoubleClickHandler → OnViewNotifyListener<T>?
finalinherited
onEditingComplete → EditTextVoidListener?
final
onError → OnViewErrorListener?
finalinherited
onHover → OnViewHoverListener?
finalinherited
onLongClick → OnViewClickListener?
finalinherited
onLongClickHandler → OnViewNotifyListener<T>?
finalinherited
onPrefixClick → OnViewClickListener?
finalinherited
onSubmitted → EditTextSubmitListener?
final
onSuffixClick → OnViewClickListener?
finalinherited
onTapOutside → EditTextTapOutsideListener?
final
onTextClick → OnViewClickListener?
finalinherited
onToggleClick → OnViewHoverListener?
finalinherited
onValid → OnViewHoverListener?
finalinherited
onValidator → OnViewValidatorListener?
finalinherited
opacity → double?
OPACITY PROPERTIES
finalinherited
opacityAlwaysIncludeSemantics → bool
finalinherited
opacityState → ValueState<double>?
finalinherited
orientation → Axis?
finalinherited
padding → double?
PADDING PROPERTIES
finalinherited
paddingBottom → double?
finalinherited
paddingCustom → EdgeInsets?
finalinherited
paddingEnd → double?
finalinherited
paddingHorizontal → double?
finalinherited
paddingStart → double?
finalinherited
paddingTop → double?
finalinherited
paddingVertical → double?
finalinherited
position → ViewPosition?
finalinherited
positionType → ViewPositionType?
finalinherited
prefixFontStyle → FontStyle?
PREFIX
finalinherited
prefixFontWeight → FontWeight?
finalinherited
prefixFontWeightState → ValueState<FontWeight>?
finalinherited
prefixText → String?
finalinherited
prefixTextAllCaps → bool
finalinherited
prefixTextColor → Color?
finalinherited
prefixTextColorState → ValueState<Color>?
finalinherited
prefixTextDecoration → TextDecoration?
finalinherited
prefixTextDecorationColor → Color?
finalinherited
prefixTextDecorationStyle → TextDecorationStyle?
finalinherited
prefixTextDecorationThickness → double?
finalinherited
prefixTextLetterSpace → double?
finalinherited
prefixTextSize → double?
finalinherited
prefixTextSizeState → ValueState<double>?
finalinherited
prefixTextState → ValueState<String>?
finalinherited
prefixTextStyle → TextStyle?
finalinherited
prefixTextStyleState → ValueState<TextStyle>?
finalinherited
prefixTextVisible → bool
finalinherited
pressedColor → Color
finalinherited
primary → Color?
final
readOnly → bool
final
restorationId → String?
final
rippleColor → Color
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
final
scrollable → bool?
finalinherited
scrollController → ScrollController?
finalinherited
scrollControllerText → ScrollController?
final
scrollingType → ViewScrollingType?
finalinherited
scrollPaddingText → EdgeInsets
final
scrollPhysicsText → ScrollPhysics?
final
secondaryColor → Color?
final
selectionColor → Color?
finalinherited
selectionControls → TextSelectionControls?
final
selectionHeightStyle → BoxHeightStyle
final
selectionWidthStyle → BoxWidthStyle
final
semanticsLabel → String?
finalinherited
shadow → double?
SHADOW PROPERTIES
finalinherited
shadowBlurRadius → double?
finalinherited
shadowBlurStyle → BlurStyle?
finalinherited
shadowBottom → double?
finalinherited
shadowColor → Color?
finalinherited
shadowEnd → double?
finalinherited
shadowHorizontal → double?
finalinherited
shadowSpreadRadius → double?
finalinherited
shadowStart → double?
finalinherited
shadowTop → double?
finalinherited
shadowType → ViewShadowType?
finalinherited
shadowVertical → double?
finalinherited
shape → ViewShape?
finalinherited
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
softWrap → bool?
finalinherited
spellCheckConfiguration → SpellCheckConfiguration?
final
strutStyle → StrutStyle?
finalinherited
suffixFontStyle → FontStyle?
SUFFIX
finalinherited
suffixFontWeight → FontWeight?
finalinherited
suffixFontWeightState → ValueState<FontWeight>?
finalinherited
suffixText → String?
finalinherited
suffixTextAllCaps → bool
finalinherited
suffixTextColor → Color?
finalinherited
suffixTextColorState → ValueState<Color>?
finalinherited
suffixTextDecoration → TextDecoration?
finalinherited
suffixTextDecorationColor → Color?
finalinherited
suffixTextDecorationStyle → TextDecorationStyle?
finalinherited
suffixTextDecorationThickness → double?
finalinherited
suffixTextLetterSpace → double?
finalinherited
suffixTextSize → double?
finalinherited
suffixTextSizeState → ValueState<double>?
finalinherited
suffixTextState → ValueState<String>?
finalinherited
suffixTextStyle → TextStyle?
finalinherited
suffixTextStyleState → ValueState<TextStyle>?
finalinherited
suffixTextVisible → bool
finalinherited
text → String?
finalinherited
textAlign → TextAlign?
finalinherited
textAllCaps → bool
finalinherited
textCapitalization → TextCapitalization
final
textColor → Color?
finalinherited
textColorState → ValueState<Color>?
finalinherited
textDecoration → TextDecoration?
finalinherited
textDecorationColor → Color?
finalinherited
textDecorationStyle → TextDecorationStyle?
finalinherited
textDecorationThickness → double?
finalinherited
textDirection → TextDirection?
finalinherited
textFontFamily → String?
finalinherited
textFontStyle → FontStyle?
finalinherited
textFontWeight → FontWeight?
finalinherited
textFontWeightState → ValueState<FontWeight>?
finalinherited
textHeightBehavior → TextHeightBehavior?
finalinherited
textLeadingDistribution → TextLeadingDistribution?
finalinherited
textOverflow → TextOverflow?
finalinherited
textSize → double?
finalinherited
textSizeState → ValueState<double>?
finalinherited
textSpans → List<TextSpan>
finalinherited
textState → ValueState<String>?
finalinherited
textStyle → TextStyle?
finalinherited
textStyleState → ValueState<TextStyle>?
finalinherited
textWidthBasis → TextWidthBasis
finalinherited
transform → Matrix4?
finalinherited
transformGravity → Alignment?
finalinherited
underlineColor → Color?
UNDERLINE PROPERTIES
final
underlineColorState → ValueState<Color>?
final
underlineHeight → double?
final
underlineHeightState → ValueState<double>?
final
undoController → UndoHistoryController?
final
visibility → bool?
finalinherited
width → double?
finalinherited
widthMax → double?
finalinherited
widthMin → double?
finalinherited
widthState → ValueState<double>?
finalinherited
wordSpacing → double?
finalinherited
wrapper → bool?
finalinherited

Methods

attach(BuildContext context, T controller) → Widget?
override
attachController(T controller) → T
override
build(BuildContext context, T controller, Widget parent) → Widget
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<YMRView<T>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
initController() → T
override
initRootProperties() → ViewRoots
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChangeDependencies(BuildContext context, T controller) → void
inherited
onDispose(BuildContext context, T controller) → void
override
onInit(BuildContext context, T controller) → void
inherited
onReady(BuildContext context, T controller) → void
override
onToggleHandler(BuildContext context, T controller) → void
inherited
onUpdateWidget(BuildContext context, T controller, dynamic oldWidget) → void
inherited
onViewCreated(BuildContext context, T controller) → void
inherited
root(BuildContext context, T controller, Widget parent) → Widget
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited