ArrowConfig class

Constructors

ArrowConfig({Widget? arrow, dynamic icon, Color? color, double? size})
const

Properties

arrow → Widget?
final
color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
final

Methods

copy({Widget? arrow, dynamic icon, double? size, Color? color}) → ArrowConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited