RawTextView class

Inheritance

Constructors

RawTextView({Key? key, String? ellipsis, String? textFontFamily, FontStyle? textFontStyle, FontWeight? textFontWeight, double? letterSpacing, double? lineHeight, Locale? locale, int? maxLines, Color? selectionColor, String? semanticsLabel, bool? softWrap, StrutStyle? strutStyle, required String? text, TextAlign? textAlign, Color? textColor, TextDecoration? textDecoration, Color? textDecorationColor, TextDecorationStyle? textDecorationStyle, double? textDecorationThickness, TextDirection? textDirection, TextHeightBehavior? textHeightBehavior, TextLeadingDistribution? textLeadingDistribution, TextOverflow? textOverflow, double? textSize, List<TextSpan> textSpans = const [], TextStyle? textStyle, TextWidthBasis textWidthBasis = TextWidthBasis.parent, double? wordSpacing, OnViewClickListener? onClick, FontStyle? prefixFontStyle, FontWeight? prefixFontWeight, String? prefixText, Color? prefixTextColor, TextDecoration? prefixTextDecoration, Color? prefixTextDecorationColor, TextDecorationStyle? prefixTextDecorationStyle, double? prefixTextDecorationThickness, double? prefixTextLetterSpace, double? prefixTextSize, TextStyle? prefixTextStyle, bool prefixTextVisible = true, OnViewClickListener? onPrefixClick, FontStyle? suffixFontStyle, FontWeight? suffixFontWeight, String? suffixText, Color? suffixTextColor, TextDecoration? suffixTextDecoration, Color? suffixTextDecorationColor, TextDecorationStyle? suffixTextDecorationStyle, double? suffixTextDecorationThickness, double? suffixTextLetterSpace, double? suffixTextSize, TextStyle? suffixTextStyle, bool suffixTextVisible = true, OnViewClickListener? onSuffixClick})
const

Properties

ellipsis → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing → double?
final
lineHeight → double?
final
locale → Locale?
final
maxLines → int?
final
onClick → OnViewClickListener?
final
onPrefixClick → OnViewClickListener?
final
onSuffixClick → OnViewClickListener?
final
prefixFontStyle → FontStyle?
PREFIX
final
prefixFontWeight → FontWeight?
final
prefixText → String?
final
prefixTextColor → Color?
final
prefixTextDecoration → TextDecoration?
final
prefixTextDecorationColor → Color?
final
prefixTextDecorationStyle → TextDecorationStyle?
final
prefixTextDecorationThickness → double?
final
prefixTextLetterSpace → double?
final
prefixTextSize → double?
final
prefixTextStyle → TextStyle?
final
prefixTextVisible → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionColor → Color?
final
semanticsLabel → String?
final
softWrap → bool?
final
strutStyle → StrutStyle?
final
suffixFontStyle → FontStyle?
SUFFIX
final
suffixFontWeight → FontWeight?
final
suffixText → String?
final
suffixTextColor → Color?
final
suffixTextDecoration → TextDecoration?
final
suffixTextDecorationColor → Color?
final
suffixTextDecorationStyle → TextDecorationStyle?
final
suffixTextDecorationThickness → double?
final
suffixTextLetterSpace → double?
final
suffixTextSize → double?
final
suffixTextStyle → TextStyle?
final
suffixTextVisible → bool
final
text → String?
final
textAlign → TextAlign?
final
textColor → Color?
final
textDecoration → TextDecoration?
final
textDecorationColor → Color?
final
textDecorationStyle → TextDecorationStyle?
final
textDecorationThickness → double?
final
textDirection → TextDirection?
final
textFontFamily → String?
final
textFontStyle → FontStyle?
final
textFontWeight → FontWeight?
final
textHeightBehavior → TextHeightBehavior?
final
textLeadingDistribution → TextLeadingDistribution?
final
textOverflow → TextOverflow?
final
textSize → double?
final
textSpans → List<TextSpan>
final
textStyle → TextStyle?
final
textWidthBasis → TextWidthBasis
final
wordSpacing → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited